@@ -2,4 +2,4 @@
 # add -I options corresponding to @INC after the first element of @ARGV,
 # then execute it
 splice @ARGV, 1, 0, map { "-I$_" } @INC; 
-exec @ARGV;
+exit(system(@ARGV) == 0 ? 0 : 1);
